package com.zbsz.filter;

import com.alibaba.fastjson2.JSONObject;
import com.common.info.CodeMsg;
import com.zbsz.info.Result;
import com.zbsz.tool.JwtTool;
import lombok.extern.slf4j.Slf4j;
import org.springframework.web.method.HandlerMethod;
import org.springframework.web.servlet.HandlerInterceptor;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import java.io.PrintWriter;

@Slf4j
public class JwtInterceptor implements HandlerInterceptor {

    //判断然后进行用户拦截
    @Override
    public boolean preHandle(HttpServletRequest request, HttpServletResponse response, Object handler) {
        // 如果不是映射到方法直接通过
        if (!(handler instanceof HandlerMethod)) {
            return true;
        }

        // 从请求头中取出 token  这里需要和前端约定好把jwt放到请求头一个叫token的地方
        String token = request.getHeader("token");

        //验证token
        if(JwtTool.verify(token)){
            return true;
        }else{
            response.setCharacterEncoding("UTF-8");
            response.setContentType("application/json; charset=utf-8");
            Result result = new Result();
            result.setCode(CodeMsg.AUTH_FAILURE.getCode());
            result.setMsg(CodeMsg.AUTH_FAILURE.getMessage());
            if (token == null) {
                log.error("-------- 票据丢失，请重新登录");
            }else{
                log.error("-------- 票据认证失败，请重新登录");
            }
            PrintWriter out = null;
            try {
                out = response.getWriter();
                out.write(JSONObject.toJSONString(result));
            } catch (Exception e) {
                e.printStackTrace();
            }finally {
                if(out != null){
                    out.flush();
                    out.close();
                }
            }
            return false;
        }
    }

}
