package com.zbsz.tool;

import com.auth0.jwt.JWT;
import com.auth0.jwt.JWTVerifier;
import com.auth0.jwt.algorithms.Algorithm;
import com.auth0.jwt.exceptions.JWTDecodeException;
import com.auth0.jwt.interfaces.DecodedJWT;

import java.util.Date;

public class JwtTool {
    private static final long EXPIRE_TIME = 15 * 60 * 60 * 1000;
    private static final String TOKEN_SECRET = "hp-xx040506070809-xxx-ppp";

    /**
     * 校验token是否正确
     *
     * @param token 密钥
     * @return 是否正确
     */
    public static boolean verify(String token) {
        try {
            Algorithm algorithm = Algorithm.HMAC256(TOKEN_SECRET);
            JWTVerifier verifier = JWT.require(algorithm).build();
            verifier.verify(token);
            return true;
        } catch (Exception exception) {
            return false;
        }
    }

    /**
     * 获得token中的信息无需secret解密也能获得
     * @return token中包含的用户名
     */
    public static String getUsername(String token) {
        try {
            DecodedJWT jwt = JWT.decode(token);
            return jwt.getClaim("loginName").asString();
        } catch (JWTDecodeException e) {
            return null;
        }
    }


    /**
     * 获取token
     * @return jwt token
     */
    public static String getToken(String username) {
        try {
            Date date = new Date(System.currentTimeMillis() + EXPIRE_TIME);//过期时间
            Algorithm algorithm = Algorithm.HMAC256(TOKEN_SECRET);//私钥及加密算法
            // 附带username，userId信息，生成签名
            return JWT.create().withAudience(username)
                    .withIssuedAt(new Date())  //发行时间
                    .withExpiresAt(date)        //有效时间
                    .withClaim("loginName", username)
                    .sign(algorithm);
        } catch (Exception e) {
            return null;
        }
    }
}
